<?php
require 'vendor/autoload.php';

use OpenAI\Client;

class ArticleGenerator {
    private $openai;
    private $apiKey;
    private $rssFeeds = [
        'elektrická auta' => [
            'https://insideevs.com/rss/',
            'https://electrek.co/feed/',
            'https://www.greencarreports.com/rss.xml'
        ],
        'ostatní auta' => [
            'https://www.autoblog.com/rss.xml',
            'https://www.caranddriver.com/rss/all.xml',
            'https://www.motor1.com/rss/'
        ]
    ];
    
    public function __construct($apiKey) {
        $this->apiKey = $apiKey;
        $this->openai = new Client([
            'api_key' => $apiKey,
        ]);
    }
    
    public function generateArticle($category, $count = 1) {
        $articles = [];
        $feeds = $this->rssFeeds[$category];
        
        for ($i = 0; $i < $count; $i++) {
            // Vyber náhodný RSS feed
            $feedUrl = $feeds[array_rand($feeds)];
            
            // Načti RSS feed
            $rss = simplexml_load_file($feedUrl);
            if (!$rss) continue;
            
            // Vyber náhodný článek
            $items = $rss->channel->item;
            if (count($items) == 0) continue;
            
            $item = $items[array_rand($items)];
            
            // Přelož článek do češtiny
            $translationPrompt = "Přelož následující článek do češtiny, zachovej formátování a přidej zdroj na konec:\n\n" . 
                               "Title: " . $item->title . "\n\n" . 
                               "Content: " . $item->description;
            
            $response = $this->openai->completions()->create([
                'model' => 'gpt-3.5-turbo',
                'prompt' => $translationPrompt,
                'max_tokens' => 2000,
                'temperature' => 0.7,
            ]);
            
            $translatedContent = $response->choices[0]->text;
            
            // Extrahuj obrázek z článku
            $imageUrl = '';
            if (isset($item->enclosure)) {
                $imageUrl = (string)$item->enclosure['url'];
            } elseif (preg_match('/<img.+?src=[\'"](.+?)[\'"].*?>/i', $item->description, $matches)) {
                $imageUrl = $matches[1];
            }
            
            $articles[] = [
                'title' => $this->extractTitle($translatedContent),
                'content' => $translatedContent,
                'image_url' => $imageUrl,
                'category' => $category,
                'source' => $this->extractSource($translatedContent)
            ];
        }
        
        return $articles;
    }
    
    private function extractTitle($article) {
        // Extract first line as title
        $lines = explode("\n", $article);
        return trim($lines[0]);
    }
    
    private function extractSource($article) {
        // Extract source from the end of the article
        if (preg_match('/Zdroj: (.*?)$/', $article, $matches)) {
            return $matches[1];
        }
        return "Zdroj: Automobilový průmysl";
    }
}

// Usage example
$apiKey = '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';
$generator = new ArticleGenerator($apiKey);

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $category = $_POST['category'] ?? 'elektrická auta';
    $count = (int)($_POST['count'] ?? 1);
    
    $articles = $generator->generateArticle($category, $count);
}
?>
<!DOCTYPE html>
<html lang="cs">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Generátor článků o autech</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            max-width: 1200px;
            margin: 0 auto;
            padding: 20px;
        }
        .article {
            margin-bottom: 30px;
            padding: 20px;
            border: 1px solid #ddd;
            border-radius: 5px;
        }
        .article img {
            max-width: 100%;
            height: auto;
            margin: 20px 0;
        }
        form {
            margin-bottom: 30px;
            padding: 20px;
            background: #f5f5f5;
            border-radius: 5px;
        }
        input, select {
            padding: 8px;
            margin: 5px;
        }
        button {
            padding: 10px 20px;
            background: #007bff;
            color: white;
            border: none;
            border-radius: 5px;
            cursor: pointer;
        }
    </style>
</head>
<body>
    <h1>Generátor článků o autech</h1>
    
    <form method="POST">
        <label for="category">Kategorie:</label>
        <select name="category" id="category">
            <option value="elektrická auta">Elektrická auta</option>
            <option value="ostatní auta">Ostatní auta</option>
        </select>
        
        <label for="count">Počet článků:</label>
        <input type="number" name="count" id="count" min="1" max="40" value="1">
        
        <button type="submit">Generovat články</button>
    </form>
    
    <?php if (isset($articles)): ?>
        <?php foreach ($articles as $article): ?>
            <div class="article">
                <h2><?php echo htmlspecialchars($article['title']); ?></h2>
                <?php if ($article['image_url']): ?>
                    <img src="<?php echo htmlspecialchars($article['image_url']); ?>" alt="<?php echo htmlspecialchars($article['title']); ?>">
                <?php endif; ?>
                <div class="content">
                    <?php echo nl2br(htmlspecialchars($article['content'])); ?>
                </div>
                <div class="source">
                    <strong><?php echo htmlspecialchars($article['source']); ?></strong>
                </div>
            </div>
        <?php endforeach; ?>
    <?php endif; ?>
</body>
</html> 